/***** interface.c ************************************************
 * Description: Routine for gathering arguments from the command
 *              line.
 * Author: Bernhard Haubold, haubold@evolbio.mpg.de
 * Date: Sun Jun 20 13:12:10 2004.
 *****************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include "interface.h"
#include "eprintf.h"

Args *args;

Args *getArgs(int argc, char *argv[]){
  char c;
  char *optString = "hvs:n:l:";

  args = (Args *)emalloc(sizeof(Args));
  args->n = 1;
  args->l = DEFAULT_L;
  args->s = 0;
  args->h = 0;
  args->v = 0;
  args->e = 0;

  c = getopt(argc, argv, optString);
  while(c != -1){
    switch(c){
    case 's':                           /* seed for random number generator */
      args->s = atoi(optarg);
      break;
    case 'n':                           /* number of iterations */
      args->n = atoi(optarg);
      break;
    case 'l':                           /* line length */
      args->l = atoi(optarg);
      break;
    case '?':                           /* fall-through is intentional */
    case 'h':                           /* print help */
      args->h = 1;
      break;
    case 'v':                           /* print version */
      args->v = 1;
      break;
    default:
      printf("# unknown argument: %c\n",c);
      args->e = 1;
      return args;
    }
    c = getopt(argc, argv, optString);
  }
  args->inputFiles = argv + optind;
  args->numInputFiles = argc - optind;
  return args;
}


void printUsage(char *version){
  printf("Usage: %s [options] [inputFiles]\n",progname());
  printf("Randomize biological sequence.\n");
  printf("randomizeSeq foo.fasta\n");
  printf("Options:\n");
  printf("\t[-s <NUM> seed for random number generator; default: randomSeed.dat, clock]\n");
  printf("\t[-n <NUM> number of iterations; default: 1]\n");
  printf("\t[-l <NUM> length of output lines; default: %d]\n",DEFAULT_L);
  printf("\t[-h print this help message and exit]\n");
  printf("\t[-v print program information and exit]\n");
  exit(0);
}

void printSplash(char *version){
  printf("%s %s\n",progname(),version);
  printf("Written by Bernhard Haubold.\n");
  printf("Distributed under the GNU General Public License.\n");
  printf("Please send bug reports to haubold@evolbio.mpg.de\n");
  exit(0);
}
